@@ -1,17 +1,19 @@
 <?php
 /**
+ * Copyright 2003-2015 Horde LLC (http://www.horde.org/)
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.horde.org/licenses/lgpl21.
+ *
+ * @author   Mike Cochrane <mike@graftonhall.co.nz>
  * @category Horde
+ * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package  Icalendar
  */
 
 /**
  * Class representing iCalendar files.
  *
- * Copyright 2003-2014 Horde LLC (http://www.horde.org/)
- *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.horde.org/licenses/lgpl21.
- *
  * @author   Mike Cochrane <mike@graftonhall.co.nz>
  * @category Horde
  * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
@@ -92,7 +94,7 @@ class Horde_Icalendar
      *
      * @return object  Reference to a Horde_Icalendar_* object as specified.
      */
-    static public function newComponent($type, $container)
+    public static function newComponent($type, $container)
     {
         $type = Horde_String::lower($type);
         $class = __CLASS__ . '_' . Horde_String::ucfirst($type);
@@ -238,6 +240,27 @@ class Horde_Icalendar
         return $result;
     }
 
+    /**
+     * Get a single value of an attribute.
+     *
+     * If multiple values, is auto-determined by library which is preferred
+     * value to return.
+     *
+     * @since 2.1.0
+     *
+     * @param string $name  The name of the attribute.
+     *
+     * @return string  The value of the attribute.
+     * @throws Horde_Icalendar_Exception
+     */
+    public function getAttributeSingle($name)
+    {
+        $out = $this->getAttribute($name, false);
+        return is_array($out)
+            ? reset($out)
+            : $out;
+    }
+
     /**
      * Gets the values of an attribute as an array.  Multiple values
      * are possible due to:
@@ -277,7 +300,7 @@ class Horde_Icalendar
      * @param mixed $default  What to return if the attribute specified by
      *                        $name does not exist.
      *
-     * @return mixed (string) The value of $name.
+     * @return mixed (mixed)  The value of $name.
      *               (mixed)  $default if $name does not exist.
      */
     public function getAttributeDefault($name, $default = '')
@@ -378,7 +401,7 @@ class Horde_Icalendar
         $r = array();
 
         foreach ($this->_components as $c) {
-            $cn = strtolower(get_class($c));
+            $cn = Horde_String::lower(get_class($c));
             if (empty($r[$cn])) {
                 $r[$cn] = 1;
             } else {
@@ -1116,7 +1139,7 @@ class Horde_Icalendar
                 $result .= $name . $params_str . ':'
                     . preg_replace(array('/(?<!\r)\n/', '/(?<!=)\r\n/'),
                                    array("\r\n", "=0D=0A=\r\n "),
-                                   Horde_Mime::quotedPrintableEncode($value))
+                                   quoted_printable_encode($value))
                     . $this->_newline;
             } else {
                 $attr_string = $name . $params_str . ':' . $value;
@@ -1516,6 +1539,10 @@ class Horde_Icalendar
             if ($value) {
                 $duration .= $value . 'S';
             }
+        } elseif ($duration === 'P') {
+            // Duration without time ("P") is NOT valid, append 0 seconds
+            // ("T0S").
+            $duration .= 'T0S';
         }
 
         return $duration;
